/*******************************************************************************
 * Copyright (C) 2018 Andreas Grimmer
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 ******************************************************************************/
package at.jku.iic.microfluidics.droplet.basic.architecture;

import java.util.Collections;
import java.util.Iterator;
import java.util.List;
import java.util.stream.Collectors;

public abstract class Biochip<K extends Edge<K>, V extends Pump<K>> implements Iterable<K> {

    /**
     * The edges represent the components of the biochip except the pump.
     */
    protected final List<K> edges;
    private final List<V> pumps;

    public Biochip(List<K> edges, List<V> pumps) {
        super();
        this.edges = edges;
        this.pumps = pumps;
    }

    public List<K> getEdges() {

        return Collections.unmodifiableList(edges);
    }
   
    public List<V> getPumps() {

        return pumps;
    }

    @Override
    public String toString() {

        return pumps.stream().map(e -> e.toString()).collect(Collectors.joining(", "))
                + edges.stream().map(e -> e.toString()).collect(Collectors.joining("\n"));
    }

    @Override
    public Iterator<K> iterator() {

        return edges.iterator();
    }

}
