/*******************************************************************************
 * Copyright (C) 2018 Andreas Grimmer
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 ******************************************************************************/
package at.jku.iic.microfluidics.droplet.basic.architecture;

import java.util.Objects;

public abstract class Pump<K extends Edge<K>> {

    /**
     * The point where the pressure or the volumetric flow rate is applied.
     */
    public final EndPoint<K> src;
    public final EndPoint<K> sink;

    public final String name;

    public Pump(EndPoint<K> src, EndPoint<K> sink, String name) {

        src = Objects.requireNonNull(src);
        sink = Objects.requireNonNull(sink);

        this.src = src;
        this.sink = sink;
        this.name = name;
    }
    
    @Override
    public String toString() {

        return name + '(' + sink.toString() + ", " + src.toString() + ')';
    }
    
    public int getEndPointHashs() {

        return (int) (0.5 * (src.id + sink.id) * (src.id + sink.id + 1) + sink.id);
    }
}
