/*******************************************************************************
 * Copyright (C) 2018 Andreas Grimmer
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 ******************************************************************************/
package at.jku.iic.microfluidics.droplet.basic.architecture.converter.dimensionator;

import java.util.Map;

import at.jku.iic.microfluidics.droplet.basic.physics.Dimensions;

public class HandChannelDimensionator implements ChannelDimensionator {

    private final Dimensions others;

    private final Map<String, Double> heights;
    private final Map<String, Double> widths;
    private final Map<String, Double> lengths;

    public HandChannelDimensionator(Map<String, Double> heights, Map<String, Double> widths, Map<String, Double> lengths,
            Dimensions others) {

        this.heights = heights;
        this.widths = widths;
        this.lengths = lengths;
        this.others = others;
    }

    @Override
    public double getHeight(String name) {

        return heights.containsKey(name) ? heights.get(name) : others.channelHeight;
    }

    @Override
    public double getWidth(String name) {

        return widths.containsKey(name) ? widths.get(name) : others.channelWidth;
    }

    @Override
    public double getLength(String name) {

        return lengths.containsKey(name) ? lengths.get(name) : others.minChannelLengthFactor * others.channelWidth;
    }
}
