/*******************************************************************************
 * Copyright (C) 2018 Andreas Grimmer
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 ******************************************************************************/
package at.jku.iic.microfluidics.droplet.basic.architecture.physical;

import org.json.JSONObject;

import at.jku.iic.microfluidics.droplet.basic.architecture.BypassChannel;
import at.jku.iic.microfluidics.droplet.basic.architecture.EndPoint;

/**
 * @author Andreas
 *
 */
public class PhysicalBypassChannel extends PhysicalEdge implements BypassChannel {

    /**
     * Initializes a bypass channel with resistance=0.
     * 
     * @param src
     * @param dst
     * @param name
     */
    public PhysicalBypassChannel(EndPoint<PhysicalEdge> src, EndPoint<PhysicalEdge> dst, String name) {

        super(src, dst, name, 1.0, 1.0, 0.0);
    }

    public PhysicalBypassChannel(EndPoint<PhysicalEdge> src, EndPoint<PhysicalEdge> dst, String name, double width, double height,
            double length) {

        super(src, dst, name, width, height, length);
    }
    

    @Override
    public int getTypeId() {

        return 4;
    }

    @Override
    JSONObject toJSON() {
        JSONObject json = new JSONObject();
        json.put("type", this.getClass().getSimpleName());
        json.put("name", name);
        json.put("srcId", src.id);
        json.put("dstId", dst.id);
        json.put("height", height);
        json.put("width", width);
        json.put("length", length);

        return json;
    }
}
