/*******************************************************************************
 * Copyright (C) 2018 Andreas Grimmer
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 ******************************************************************************/
package at.jku.iic.microfluidics.droplet.basic.architecture.physical;

import java.util.List;

import org.json.JSONObject;

import at.jku.iic.microfluidics.droplet.basic.architecture.Edge;
import at.jku.iic.microfluidics.droplet.basic.architecture.EndPoint;

public abstract class PhysicalEdge extends Edge<PhysicalEdge> implements MatlabInterface {

    protected double width;
    protected double height;
    public double length;

    public PhysicalEdge(EndPoint<PhysicalEdge> src, EndPoint<PhysicalEdge> dst, String name, double width, double height, double length) {
        super(src, dst, name);
        this.width = width;
        this.height = height;
        this.length = length;

        if (width < height) {
            // System.out.println("Violation of the width < height constraint! (Potentially used for visualization)");
//            throw new RuntimeException(
//                    "Usually the condition width < height has to be satisfied in order to correctly calculate the resistance of the edge "
//                            + name + "!");
        }
    }

    public double getResistance(double muC) {

        return getResistance(muC, width, height, length);
    }

    public static double getAFactor(double width, double height) {

        return 12 * (1 / (1 - 192 * height / (Math.pow(Math.PI, 5) * width) * Math.tanh(Math.PI * width / (2 * height))));
    }

    public static double getResistance(double muC, double width, double height, double length) {

        return length * getAFactor(width, height) * muC / (width * Math.pow(height, 3));
    }

    public double getWidth() {

        return width;
    }

    public double getHeight() {

        return height;
    }

    public double getLength() {

        return length;
    }

    @Override
    public List<PhysicalEdge> getHeaderSuccessorEdges() {

        throw new UnsupportedOperationException(
                "This method is not yet implemented! The method requires the system state. See simulator based on the electrical model.");
    }

    @Override
    public List<PhysicalEdge> getPayloadSuccessorEdges() {

        throw new UnsupportedOperationException(
                "This method is not yet implemented! The method requires the system state. See simulator based on the electrical model.");
    }

	abstract JSONObject toJSON();

}
