/*******************************************************************************
 * Copyright (C) 2018 Andreas Grimmer
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 ******************************************************************************/
package at.jku.iic.microfluidics.droplet.basic.architecture.physical;

import at.jku.iic.microfluidics.droplet.basic.architecture.EndPoint;
import at.jku.iic.microfluidics.droplet.basic.architecture.Module;
import at.jku.iic.microfluidics.droplet.basic.architecture.converter.GraphToStructureBiochipConverter;

/**
 * @author Andreas Grimmer
 *
 */
public abstract class PhysicalModule extends PhysicalEdge implements Module, PlaceAndRouteSerialization {

    private final char operation;

    public PhysicalModule(EndPoint<PhysicalEdge> src, EndPoint<PhysicalEdge> dst, String name, char operation, double width, double height,
            double length) {

        super(src, dst, name, width, height, length);
        this.operation = operation;
    }

    public boolean isFirstPartOfModule() {

        return super.isFirstPartOfModule();
    }

    @Override
    public char getOperation() {

        return operation;
    }

    @Override
    public String getStringRepresentation(ComponentCounter componentCounter) {

        StringBuilder sb = new StringBuilder();
        if (isFirstPartOfModule()) {
            sb.append("module").append(';');
            sb.append(name.substring(0, name.lastIndexOf(GraphToStructureBiochipConverter.MODULE_SUFFIX_1))).append(';');
            sb.append(src.id).append(';');
            sb.append(dst.getSuccessors().get(0).dst.id).append(';');
            
            // As we do not know the dimensions of the module,
            // use a square with the length of the forwarding channel
            PhysicalChannel forwardingChannel = (PhysicalChannel) src.getSuccessors().stream().filter(e -> e.isChannel()).findFirst().get();
            sb.append((int) (forwardingChannel.length * 1E06)).append(';');
            sb.append((int) (forwardingChannel.length * 1E06));
            sb.append('\n');
        }
        return sb.toString();
    }
    
    @Override
    public int getTypeId() {

        return 3;
    }
}
