/*******************************************************************************
 * Copyright (C) 2018 Andreas Grimmer
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 ******************************************************************************/
package at.jku.iic.microfluidics.droplet.basic.architecture.physical;

import org.json.JSONObject;

import at.jku.iic.microfluidics.droplet.basic.architecture.EndPoint;
import at.jku.iic.microfluidics.droplet.basic.architecture.Pump;

/**
 * @author Andreas
 *
 */
public abstract class PhysicalPump extends Pump<PhysicalEdge> implements MatlabInterface, PlaceAndRouteSerialization {

    public PhysicalPump(EndPoint<PhysicalEdge> pressureSrc, EndPoint<PhysicalEdge> pressureDst, String name) {
        super(pressureSrc, pressureDst, name);
    }

    @Override
    public String getStringRepresentation(ComponentCounter componentCounter) {

        StringBuilder sb = new StringBuilder();
        sb.append("pump").append(';');
        sb.append('p').append(componentCounter.getPumpCounter()).append(';');
        componentCounter.incPumpCounter();
        sb.append(src.id);
        sb.append('\n');

        sb.append("waste").append(';');
        sb.append('w').append(componentCounter.getWasteChamberCounter()).append(';');
        componentCounter.incWasteChamberCounter();
        sb.append(sink.id);
        sb.append('\n');

        return sb.toString();
    }

    abstract JSONObject toJSON();
}
