/*******************************************************************************
 * Copyright (C) 2018 Andreas Grimmer
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 ******************************************************************************/
package at.jku.iic.microfluidics.droplet.basic.architecture.physical.defective;

import java.util.List;

import at.jku.iic.microfluidics.droplet.basic.architecture.EndPoint;
import at.jku.iic.microfluidics.droplet.basic.architecture.physical.LaplacePressureParameter;
import at.jku.iic.microfluidics.droplet.basic.architecture.physical.PhysicalEdge;
import at.jku.iic.microfluidics.droplet.basic.architecture.physical.TrappablePhysicalModule;

public class DefectiveTrappablePhysicalModule extends TrappablePhysicalModule {

	private double defectWidth;
	private double defectHeight;
	private double defectLength;

	public DefectiveTrappablePhysicalModule(EndPoint<PhysicalEdge> src, EndPoint<PhysicalEdge> dst, String name,
			char operation, double width, double height, double length,
			List<LaplacePressureParameter> laplacePressureParameters, double defectWidth, double defectHeight,
			double defectLength) {
		super(src, dst, name, operation, width, height, length, laplacePressureParameters);
        this.defectWidth = defectWidth;
        this.defectHeight = defectHeight;
        this.defectLength = defectLength;
	}

    protected double getDefectWidth() {
    	return defectWidth;
    }
    protected double getDefectHeight() {
    	return defectHeight;
    }
    protected double getDefectLength() {
    	return defectLength;
    }
    
    public void setDefectWidth(double defectWidth) {
    	this.defectWidth = defectWidth;
    }
    public void setDefectHeight(double defectHeight) {
    	this.defectHeight = defectHeight;
    }
    public void setDefectLength(double defectLength) {
    	this.defectLength = defectLength;
    }
    public void setDefects(double defectWidth, double defectHeight, double defectLength) {
    	this.defectWidth = defectWidth;
    	this.defectHeight = defectHeight;
    	this.defectLength = defectLength;
    }

	public void resetDefects() {
		this.defectWidth = 1.0;
    	this.defectHeight = 1.0;
    	this.defectLength = 1.0;
	}
}
