/*******************************************************************************
 * Copyright (C) 2018 Andreas Grimmer
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 ******************************************************************************/
package at.jku.iic.microfluidics.droplet.basic.architecture.structure;

import java.util.List;
import java.util.stream.Collectors;
import java.util.stream.Stream;
import org.json.JSONObject;
import at.jku.iic.microfluidics.droplet.basic.architecture.Edge;
import at.jku.iic.microfluidics.droplet.basic.architecture.EndPoint;

public abstract class StructureEdge extends Edge<StructureEdge> {

    public StructureEdge(EndPoint<StructureEdge> src, EndPoint<StructureEdge> dst, String name) {
        super(src, dst, name);
    }

    @Override
    public List<StructureEdge> getHeaderSuccessorEdges() {

        Stream<StructureEdge> stream = dst.getSuccessors().stream().filter(e -> !e.isBypassChannel());
        if (dst.isLeeSorter) {
            // In this case, make a discrete decision where the header flows into.
            stream.filter(e -> e.isChannel());
        }
        return stream.collect(Collectors.toList());
    }

    @Override
    public List<StructureEdge> getPayloadSuccessorEdges() {

        Stream<StructureEdge> stream = dst.getSuccessors().stream().filter(e -> !e.isBypassChannel());
        if (dst.isLeeSorter) {
            // In this case, make a discrete decision where the header flows into.
            stream.filter(e -> e.isModule());
        }
        return stream.collect(Collectors.toList());
    }

    abstract public JSONObject toJSON();
}
