/*******************************************************************************
 * Copyright (C) 2018 Andreas Grimmer
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 ******************************************************************************/
package at.jku.iic.microfluidics.droplet.basic.dumper;

import java.io.FileNotFoundException;
import java.io.PrintWriter;
import java.nio.file.Paths;
import java.text.DecimalFormat;

import at.jku.iic.microfluidics.droplet.basic.architecture.physical.PhysicalBiochip;
import at.jku.iic.microfluidics.droplet.basic.architecture.physical.PhysicalEdge;
import at.jku.iic.microfluidics.droplet.basic.architecture.physical.PhysicalPump;
import at.jku.iic.microfluidics.utils.dumper.Dumper;
import at.jku.iic.microfluidics.utils.dumper.GMLDumper;

public class PhysicalBiochipDumper extends BiochipDumper<PhysicalEdge, PhysicalPump> {
    
    private PhysicalBiochipDumper(PrintWriter writer, Dumper dumper, PhysicalBiochip chip) {
        super(writer, dumper, chip);
    }

    public static void printGraph(PhysicalBiochip chip, String fileName) {

        try {
            PrintWriter pw = new PrintWriter(Paths.get(fileName + ".gml").toFile());
            PhysicalBiochipDumper dumper = new PhysicalBiochipDumper(pw, new GMLDumper(), chip);
            dumper.dump();
            pw.close();
        } catch (FileNotFoundException e) {
            System.err.println("Cannot open file");
            e.printStackTrace();
        }
    }

    @Override
    public String getEdgeLabel(PhysicalEdge edge) {
    
        // Prints the name, the index (for allowing to use it within Matlab) and the resistance of an edge.
        DecimalFormat f = new DecimalFormat("0.##E0");
        return edge.name + '(' + (chip.getEdges().indexOf(edge) + 1) + ')' + "=" + f.format(edge.getResistance(((PhysicalBiochip) chip).fluidProperties.muC));
    }

}
