/*******************************************************************************
 * Copyright (C) 2018 Andreas Grimmer
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 ******************************************************************************/
package at.jku.iic.microfluidics.droplet.basic.injection.discrete;

import at.jku.iic.microfluidics.droplet.basic.architecture.discrete.DiscretePump;
import at.jku.iic.microfluidics.droplet.basic.injection.DropletInjectionTime;

/**
 * Represents a discrete injection time. The time point is given as an 
 * amount of time steps elapsed from the beginning of the experiment.
 * 
 * @author Andreas Grimmer &lt;andreas.grimmer@jku.at&gt;
 */
public abstract class DiscreteDropletInjectionTime extends DropletInjectionTime<DiscretePump> implements Comparable<DiscreteDropletInjectionTime> {

    /**
     * The time steps elapsed from the beginning of the experiment.
     */
    public int timePoint;

    public DiscreteDropletInjectionTime(DiscretePump pump, int timePoint) {
        super(pump);
        this.timePoint = timePoint;
    }
    
    @Override
    public int compareTo(DiscreteDropletInjectionTime o) {
    
        return timePoint - o.timePoint;
    }
}
