/*******************************************************************************
 * Copyright (C) 2018 Andreas Grimmer
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 ******************************************************************************/
package at.jku.iic.microfluidics.droplet.basic.physics;

import at.jku.iic.microfluidics.droplet.basic.architecture.physical.PhysicalChannel;

public class Dimensions {

    public final double channelWidth;
    public final double channelHeight;

    public final double leeSortingLength;
    public final double leeSortingWidth;

    public final double moduleWidth1;
    public final double moduleHeight1;
    public final double moduleLength1;

    public final double moduleWidth2;
    public final double moduleHeight2;
    public final double moduleLength2;

    public final double forwardingChannelWidth;
    public final double forwardingChannelHeight;
    public final double forwardingChennelLength;
    
    public final double bifurcationDefaultSuccessorLength;
    public final double bifurcationNonDefaultSuccessorLength;

    public final int minChannelLengthFactor;
    public final int maxChannelLengthFactor;
    
    public final double minChannelResistance;
    public final double maxChannelResistance;

    public Dimensions(double channelWidth, double channelHeight, double leeSortingLength, double leeSortingWidth, double moduleWidth1,
            double moduleHeight1, double moduleLength1, double moduleWidth2, double moduleHeight2, double moduleLength2,
            double forwardingChannelWidth, double forwardingChannelHeight, double forwardingChennelLength,
            double bifurcationDefaultSuccessorLength, double bifurcationNonDefaultSuccessorLength,
            int minChannelLengthFactor, int maxChannelLengthFactor, double muC) {
        super();
        this.channelWidth = channelWidth;
        this.channelHeight = channelHeight;
        this.leeSortingLength = leeSortingLength;
        this.leeSortingWidth = leeSortingWidth;
        this.moduleWidth1 = moduleWidth1;
        this.moduleHeight1 = moduleHeight1;
        this.moduleLength1 = moduleLength1;
        this.moduleWidth2 = moduleWidth2;
        this.moduleHeight2 = moduleHeight2;
        this.moduleLength2 = moduleLength2;
        this.forwardingChannelWidth = forwardingChannelWidth;
        this.forwardingChannelHeight = forwardingChannelHeight;
        this.forwardingChennelLength = forwardingChennelLength;
        this.bifurcationDefaultSuccessorLength = bifurcationDefaultSuccessorLength;
        this.bifurcationNonDefaultSuccessorLength = bifurcationNonDefaultSuccessorLength;
        this.minChannelLengthFactor = minChannelLengthFactor;
        this.maxChannelLengthFactor = maxChannelLengthFactor;
        this.minChannelResistance = PhysicalChannel.getResistance(muC, channelWidth, channelHeight,
                minChannelLengthFactor * channelWidth);
        this.maxChannelResistance = PhysicalChannel.getResistance(muC, channelWidth, channelHeight,
                maxChannelLengthFactor * channelWidth);
    }

    private static final double STD_CHANNEL_WIDTH = 50e-06;
    private static final double STD_CHANNEL_HEIGHT = 50e-06;

    private static final double STD_LEE_SORTING_LENGTH = STD_CHANNEL_WIDTH * 1.5;
    private static final double STD_LEE_SORTING_WIDTH = 80e-06;

    private static final double STD_MODULE_WIDTH1 = 300e-06;
    private static final double STD_MODULE_HEIGHT1 = STD_CHANNEL_HEIGHT;
    private static final double STD_MODULE_LENGHT1 = STD_CHANNEL_WIDTH;

    private static final double STD_MODULE_WIDTH2 = STD_CHANNEL_WIDTH;
    private static final double STD_MODULE_HEIGHT2 = STD_CHANNEL_HEIGHT;
    private static final double STD_MODULE_LENGHT2 = 15 * STD_CHANNEL_WIDTH;

    private static final double STD_FORWARDING_CHANNEL_WIDTH = STD_CHANNEL_WIDTH;
    private static final double STD_FORWARDING_CHANNEL_HEIGHT = STD_CHANNEL_HEIGHT;
    private static final double STD_FORWARDING_CHANNEL_LENGHT = 24 * STD_CHANNEL_WIDTH;

    // private static final double STD_MODULE_RESISTANCE1 = 1.7868e+10;
    // private static final double STD_MODULE_RESISTANCE2 = 3.3917e+12;
    // private static final double STD_FORWARDING_CHANNEL_RESISTANCE = 5.4267e+12;

    private static final int STD_MIN_CHANNEL_LENGTH_FACTOR = 4;
    private static final int STD_MAX_CHANNEL_LENGTH_FACTOR = 92;

    public static Dimensions getDefaultSettings(FluidProperties fluidProperties) {

        return new Dimensions(STD_CHANNEL_WIDTH, STD_CHANNEL_HEIGHT, STD_LEE_SORTING_LENGTH, STD_LEE_SORTING_WIDTH, STD_MODULE_WIDTH1,
                STD_MODULE_HEIGHT1, STD_MODULE_LENGHT1, STD_MODULE_WIDTH2, STD_MODULE_HEIGHT2, STD_MODULE_LENGHT2,
                STD_FORWARDING_CHANNEL_WIDTH, STD_FORWARDING_CHANNEL_HEIGHT, STD_FORWARDING_CHANNEL_LENGHT,
                7.5 * STD_CHANNEL_WIDTH, 8 * STD_CHANNEL_WIDTH,
                STD_MIN_CHANNEL_LENGTH_FACTOR, STD_MAX_CHANNEL_LENGTH_FACTOR, fluidProperties.muC);
    }
}
