/*******************************************************************************
 * Copyright (C) 2018 Andreas Grimmer
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 ******************************************************************************/
package at.jku.iic.microfluidics.droplet.basic.state;

import java.util.List;

import at.jku.iic.microfluidics.droplet.basic.architecture.Edge;

/**
 * Describes the position of a droplet in terms of the current channel and the covered path at a certain time
 * step.
 * 
 * @author Andreas Grimmer &lt;andreas.grimmer@jku.at&gt;
 *
 */
public abstract class DropletState<K extends Edge<K>, D extends DropletState<K,D>> implements Comparable<DropletState<K,D>> {


    protected final D predecessor;

    /**
     * The name of the droplet.
     */
    public final String name;

    public DropletState(String name) {
        super();
        this.name = name;
        this.predecessor = null;
    }

    protected DropletState(D predecessor, String name) {
        super();
        this.name = name;
        this.predecessor = predecessor;
    }

    public abstract List<K> getSuccessorChannels();
    
    /**
     * This compare is used for sorting droplet states by their name.
     */
    @Override
    public int compareTo(DropletState<K, D> o) {
    
        return name.compareTo(o.name);
    }

    public abstract D getPredecessor();
}
