/*******************************************************************************
 * Copyright (C) 2018 Andreas Grimmer
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 ******************************************************************************/
package at.jku.iic.microfluidics.droplet.electric.simulator.gui.components;

import java.util.ArrayList;

import at.jku.iic.microfluidics.droplet.electric.simulator.gui.inout.RedrawHandler;
import at.jku.iic.microfluidics.droplet.electric.simulator.gui.inout.Window;

/**
 * Class SceneHandler implements RedrawHandler and manages a Drawable list
 */
public class SceneHandler implements RedrawHandler {

    private ArrayList<Drawable> drawableArr = new ArrayList<Drawable>();

    /**
     * Draws all drawables of the list
     */
    @Override
    public synchronized void redraw(Window window, int width, int height) {

        for (Drawable d : drawableArr) {
            d.draw(window);
        }
    }

    /**
     * Add a new drawable
     * 
     * @param d
     *            the drawable to add
     */
    public synchronized void addDrawable(Drawable d) {

        drawableArr.add(d);
    }

    public synchronized void removeDrawable(Drawable d) {
        
        drawableArr.remove(d);
    }
}
