/*******************************************************************************
 * Copyright (C) 2018 Andreas Grimmer
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 ******************************************************************************/
package at.jku.iic.microfluidics.droplet.electric.simulator.gui.components;

import at.jku.iic.microfluidics.droplet.electric.simulator.gui.inout.Window;

/**
 * Abstract class TextDrawable that implements Drawable 
 */
public abstract class TextDrawable implements Drawable {

	// The x and y coordinate
	private final int x;
	private final int y;
			
	/**
	 * @param x the x-coordinate
	 * @param y the y-coordinate
	 */
	public TextDrawable(int x, int y) {
		this.x = x;
		this.y = y;
	}

	/**
	 * Abstract method getText
	 * @return Returns the text as String
	 */
	public abstract String getText();

	/**
	 * Draws a text centered
	 */
	@Override
	public void draw(Window window) {
		window.drawText(getText(), x, y);
	}
}
