/*******************************************************************************
 * Copyright (C) 2018 Andreas Grimmer
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 ******************************************************************************/
package at.jku.iic.microfluidics.droplet.electric.simulator.state;

import java.util.Collections;
import java.util.List;
import java.util.Map;
import java.util.Set;

import at.jku.iic.microfluidics.droplet.basic.architecture.physical.CloggablePhysicalChannel;
import at.jku.iic.microfluidics.droplet.basic.architecture.physical.PhysicalEdge;
import at.jku.iic.microfluidics.droplet.electric.simulator.event.Event;

/**
 * Represents the position of a droplet, which is flowing in a channel.
 * 
 * @author Andreas Grimmer &lt;andreas.grimmer@jku.at&gt;
 *
 */
public class DropletEntireChannelPosition extends DropletPosition {

    public DropletEntireChannelPosition(PhysicalEdge edge, boolean defaultFlowDirection, double dropletVolume) {
        super(edge, defaultFlowDirection, dropletVolume);
    }

    @Override
    public double getTimeDifferenceToNextEvent(Map<PhysicalEdge, Double> flowRates, double slipFactor) {

        return Double.MAX_VALUE;
    }

    @Override
    public double getDropletLength() {

        return edge.getLength();
    }

    @Override
    public List<DropletPosition> moveDroplet(double timeDifference, Map<PhysicalEdge, Double> flowRates,
            Set<CloggablePhysicalChannel> cloggedChannels, Event event, double dropletVolumeShift, double slipFactor) {

        return Collections.singletonList(new DropletEntireChannelPosition(edge, defaultFlowDirection, dropletVolume));
    }
    
    @Override
    public String toString() {
    
        return "Entire; " + edge.name + "; " + defaultFlowDirection;
    }
    
    @Override
    public void accept(DropletPositionVisitor v) {
    
        v.visitEntire(this);
    }
}
