package at.jku.iic.microfluidics.droplet.improvedrobustness.testarchitectures.syntheticchip;

import java.util.List;
import java.util.ArrayList;
import java.util.Collection;
import java.util.HashMap;
import java.util.Map;

import org.json.JSONArray;
import org.json.JSONObject;

public class Experiment {
    public String name;
    public List<String> injectionOrder = new ArrayList<>();
    public List<Double> dropletDistances = new ArrayList<>();
    public Map<String, DropletPath> paths = new HashMap<>();

    public Experiment(String name) {
        this.name = name;
    }

    public DropletPath addDropletPath(DropletPath path) {
        return paths.put(path.dropletName, path);
    }
    
    public Collection<DropletPath> getDropletPaths() {
		return paths.values();
	}

    public JSONObject toJSON(){
        JSONObject json = new JSONObject();
        json.put("name", name);
        json.put("injectionOrder", injectionOrder);
        json.put("dropletDistances", dropletDistances);

        //paths
        JSONArray jsonPaths = new JSONArray();
        json.put("paths", jsonPaths);
        for (DropletPath path : paths.values()) {
            jsonPaths.put(path.toJSON());
        }

        return json;
    }

    public static Experiment fromJSON(JSONObject json) {
        String name = json.getString("name");
        JSONArray jsonInjectionOrder = json.getJSONArray("injectionOrder");
        JSONArray jsonDropletDistances = json.getJSONArray("dropletDistances");
        JSONArray jsonPaths = json.getJSONArray("paths");

        Experiment experiment = new Experiment(name);

        //injectionOrder
        for (int i = 0; i < jsonInjectionOrder.length(); i++) {
            experiment.injectionOrder.add(jsonInjectionOrder.getString(i));
        }

        //dropletDistances
        for (int i = 0; i < jsonDropletDistances.length(); i++) {
            experiment.dropletDistances.add(jsonDropletDistances.getDouble(i));
        }

        //paths
        for (int i = 0; i < jsonPaths.length(); i++) {
            experiment.addDropletPath(DropletPath.fromJSON(jsonPaths.getJSONObject(i)));
        }

        return experiment;
    }
}
