/* ************************************************************************** *
 *                                                                            *
 * LimitedSizeHashMap                                                         *
 *                                                                            *
 * IEC Static Code Analysis                                                   *
 * Institute for System Software, Johannes Kepler University, Linz            *
 *                                                                            *
 * Copyright (c) 2012, Johannes Kepler University, Linz                       *
 *                                                                            *
 * ************************************************************************** */
package at.jku.iic.microfluidics.utils;

import java.util.LinkedHashMap;

/**
 * A hash map having a fixed capacity.
 * 
 * @author Florian Angerer, December 2011
 * @version 1.0
 * @since 1.0
 * 
 */
public class LimitedSizeHashMap<K, V> extends LinkedHashMap<K, V> {

    /** serial version UID */
    private static final long serialVersionUID = 72201022805860609L;

    /** the capacity of the limited size hash map */
    private int capacity;

    /**
     * Constructor initializing the hash map with a capacity. The hash map will
     * never contain more elements than the capacity allows. It always removes
     * the oldest element.
     * 
     * @param capacity
     *            the capacity of the hash map
     */
    public LimitedSizeHashMap(final int capacity) {
        
        super();
        this.capacity = capacity;
    }
    
    public void setCapacity(int capacity) {
        
        this.capacity = capacity;
    }
    
    public int getCapacity() {
        
        return capacity;
    }

    /*
     * (non-Javadoc)
     * 
     * @see java.util.LinkedHashMap#removeEldestEntry(java.util.Map.Entry)
     */
    @Override
    protected boolean removeEldestEntry(java.util.Map.Entry<K, V> eldest) {
        return size() > capacity;
    }
}
