package at.jku.iic.microfluidics.utils;

/**
 * A simple class encapsulating three objects of arbitrary types into one object with three
 * components (a triple).
 * 
 * @param <S>
 *            type of the first component
 * @param <T>
 *            type of the second component
 * @param <U>
 *            type of the third component
 * 
 * @author Florian Angerer, July 2011
 * @version 1.0
 * @since 1.0
 * 
 */
public final class Triple<S, T, U> {

    /** the first component of this triple */
    public S first;

    /** the second component of this triple */
    public T second;

    /** the third component of this triple */
    public U third;

    /**
     * Constructor initializing the first, the second and the third component of this triple.<br>
     * 
     * @param first
     *            the first component
     * @param second
     *            the second component
     * @param third
     *            the third component
     */
    public Triple(S first, T second, U third) {
        super();
        this.first = first;
        this.second = second;
        this.third = third;
    }

    /*
     * (non-Javadoc)
     * 
     * @see java.lang.Object#hashCode()
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((first == null) ? 0 : first.hashCode());
        result = prime * result + ((second == null) ? 0 : second.hashCode());
        result = prime * result + ((third == null) ? 0 : third.hashCode());
        return result;
    }

    /*
     * (non-Javadoc)
     * 
     * @see java.lang.Object#equals(java.lang.Object)
     */
    @SuppressWarnings("rawtypes")
    @Override
    public boolean equals(Object obj) {
        if (this == obj) return true;
        if (obj == null) return false;
        if (getClass() != obj.getClass()) return false;
        Triple other = (Triple) obj;
        if (first == null) {
            if (other.first != null) return false;
        } else if (!first.equals(other.first)) return false;
        if (second == null) {
            if (other.second != null) return false;
        } else if (!second.equals(other.second)) return false;
        if (third == null) {
            if (other.third != null) return false;
        } else if (!third.equals(other.third)) return false;
        return true;
    }

    /*
     * (non-Javadoc)
     * 
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        return "Triple [first=" + first + ", second=" + second + ", third=" + third + "]";
    }

}
