/*******************************************************************************
 * Copyright (C) 2018 Andreas Grimmer
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 ******************************************************************************/
package at.jku.iic.microfluidics.utils.dumper;

import java.awt.Color;
import java.io.PrintWriter;

/**
 * Dumper implementation using the DOT language (from Graphviz collection).<br>
 * <p>
 * For a detailed specification of the DOT language visit <a href=
 * "http://www.graphviz.org/content/dot-language" >The DOT Language</a> (July 2012).
 * </p>
 * <p>
 * This implementation dumps a call graph to the provided writer using the DOT language.<br>
 * DOT code looks like following:<br>
 * <code>
 * digraph {<br>
 * &nbsp;&nbsp;node [shape=box]<br>
 * &nbsp;&nbsp;node0 label["Node 0"]<br>
 * &nbsp;&nbsp;node1 label["Node 1"]<br>
 * &nbsp;&nbsp;node0 -> node1;<br>
 * }<br>
 * </code>
 * </p>
 * 
 * @author Florian Angerer, November 2011
 * @version 1.3
 * @since 1.0
 * 
 */
public class GraphvizDumper implements Dumper {

    /*
     * (non-Javadoc)
     * 
     * @see at.jku.ssw.kemroiec.callGraph.dumper.CallGraphDumper_v2#generateNode(
     * at.jku.ssw.kemroiec.callGraph.CGNode2, java.lang.String)
     */
    @Override
    public void generateNode(PrintWriter w, final String n, final String nodeID) {
        assert n != null;

        w.append(nodeID).append(" [label=\"").append(n).append("\"] \n");
    }
    
    
	@Override
    public void generateNode(PrintWriter w, String n, String nodeID,
			Color nodeColor) {
		throw new java.lang.UnsupportedOperationException("Coloring a graphviz graph is not supported");
	}

    /*
     * (non-Javadoc)
     * 
     * @see at.jku.ssw.kemroiec.callGraph.dumper.CallGraphDumper_v2#generateHeader()
     */
    @Override
    public void generateHeader(PrintWriter w) {
        w.append("digraph { node [shape=box]; ");
    }

    /*
     * (non-Javadoc)
     * 
     * @see at.jku.ssw.kemroiec.callGraph.dumper.CallGraphDumper_v2#generateTrailer()
     */
    @Override
    public void generateTrailer(PrintWriter w) {
        w.append("\n}");
    }


	@Override
	public void generateEdge(PrintWriter w, String src, String description,
			String dest) {
		assert src != null;
        assert dest != null;
        assert w != null;

        w.append(src).append(" -> ").append(dest).append(";");
		
	}


	@Override
	public void generateEdge(PrintWriter w, String src, String description,
			String dest, Color color, boolean dashed) {
		throw new java.lang.UnsupportedOperationException("Coloring a graphviz graph is not supported");
		
	}
}
